darkhistory.electrons.ics.ics\_cooling
======================================

.. automodule:: darkhistory.electrons.ics.ics_cooling

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree: ics_cooling
   
      get_ics_cooling_tf
      get_ics_cooling_tf_fast
   
   

   
   
   

   
   
   